@@ -13,23 +13,27 @@ ds9.py connects python and ds9 via the xpa messaging system:
 
 - The ds9 class constructor connects to a single instance of a running ds9. 
 - The ds9 object supports 'set' and 'get' methods to communicate with ds9.
-- Other methods send/retrieve numpy arrays and pyfits hdulists to/from ds9.
+- Send/retrieve numpy arrays and pyfits (or astropy) hdulists to/from ds9.
 - The ds9_targets() function lists ds9 programs running on your system.
 - The ds9_openlist() function connects to a list of running ds9 instances.
 
 """
 
 # pyds9 version
-__version__ = '1.4'
+__version__ = '1.6'
 
 try:
-    import pyfits
-    if pyfits.__version__ >=  '2.2':
-        _have_pyfits = 1
-    else:
-        _have_pyfits = 0
+    from astropy.io import fits as pyfits
+    _have_pyfits = 1
 except:
-    _have_pyfits = 0
+    try:
+        import pyfits
+        if pyfits.__version__ >=  '2.2':
+            _have_pyfits = 2
+        else:
+            _have_pyfits = 0
+    except:
+        _have_pyfits = 0
 
 try:
     import numpy
@@ -185,8 +189,8 @@ class ds9(object):
 
     - get_arr2np: retrieve a FITS image or an array into a numpy array
     - get_np2arr: send a numpy array to ds9 for display
-    - get_pyfits: retrieve a FITS image into a pyfits hdu list
-    - set_pyfits: send a pyfits hdu list to ds9 for display
+    - get_pyfits: retrieve a FITS image into a pyfits (or astropy) hdu list
+    - set_pyfits: send a pyfits (or astropy) hdu list to ds9 for display
 
     """
 
@@ -357,6 +361,20 @@ class ds9(object):
         
           >>> d.set("array [xdim=1024 ydim=1024 bitpix=-32]", arr)
 
+        Sending both a paramlist and data is the canonical way to send a region
+        to ds9::
+
+          >>> d.set('regions', 'fk5; circle(345.29,58.87,212.58")');
+          1
+
+        This is equivalent to the Unix xpaset command:
+
+          echo 'fk5; circle(345.29,58.87,212.58")' | xpaset ds9 regions
+
+        Indeed, if you are having problems with ds9.set() or ds9.get(), it
+        often is helpful to try the equivalent command using the Unix xpaset
+        and xpaget programs.
+
         """
 	self._selftest()
         if _have_numpy and type(buf) == numpy.ndarray:
@@ -431,7 +449,10 @@ class ds9(object):
             if not _have_pyfits:
                 raise ValueError, 'set_pyfits not defined (pyfits not found)'
             if type(hdul) != pyfits.HDUList:
-                raise ValueError, 'requires pyfits.HDUList as input'
+                if _have_pyfits == 1:
+                    raise ValueError, 'requires pyfits.HDUList as input'
+                else:
+                    raise ValueError, 'requires astropy.HDUList as input'
             newFitsFile = StringIO.StringIO()
             hdul.writeto(newFitsFile)
             newfits = newFitsFile.getvalue()
@@ -525,6 +546,8 @@ class ds9(object):
                     narr = arr.astype(numpy.float32)
                 else:
                     narr = arr
+            if not narr.flags['C_CONTIGUOUS']:
+                narr = numpy.ascontiguousarray(narr)
             bp = _np2bp(narr.dtype)
             buf = narr.tostring('C')
             blen = len(narr.data)
@@ -603,7 +626,7 @@ if __name__ == '__main__':
             print "\nskipping numpy test ..."
 
         if _have_pyfits:
-            print "\ntesting pyfits support ..."
+            print "\ntesting pyfits support (%d) ..." % _have_pyfits
             hdul = d.get_pyfits()
             print hdul.info()
             i = hdul[0].data
